@@ -1,4 +1,4 @@
-from djraphql.util.django_models import get_pk_fields_for_model
+from djraphql.django_models import get_pk_fields_for_model
 
 
 class TypeRegistry:
@@ -179,13 +179,13 @@ class TypeRegistry:
         return result
 
     def get_pk_fields_for_model(self, model_class):
-        """Convenience class that wraps a utility method that gets the primary-key
+        """Convenience method that wraps a utility method that gets the primary-key
         fields on a model.
         """
         return get_pk_fields_for_model(model_class, self.get_available_model_classes())
 
     def get_graphene_type_or_default(self, model_field):
-        """Convenience class that returns the appropriate Graphene type for a
+        """Convenience method that returns the appropriate Graphene type for a
         ModelField.
 
         Args:
@@ -195,7 +195,7 @@ class TypeRegistry:
                 a graphene_type (set by the user), use that. Otherwise the schema's
                 type mapping is used .
         """
-        # If the ModelField specifies its desire graphene_type, use it
+        # If the ModelField specifies its desired graphene_type, use it
         if model_field.graphene_type:
             return model_field.graphene_type
 
